@@ -46,12 +46,14 @@ pub fn decrypt_file(
     drop(reader);
 
     if sha_sum {
+        let start_time = Instant::now();
         let mut hash = [0u8; 32];
         let mut hasher = KangarooTwelve::new(&[]);
         hasher.update(&data);
         hasher.finalize(&mut hash);
         let hash_b64 = base64::encode(hash);
-        println!("Hash of the encrypted file is: {}", hash_b64);
+        let duration = start_time.elapsed();
+        println!("Hash of the encrypted file is: {} [took {:.2}s]", hash_b64, duration.as_secs_f32());
 
         let answer = get_answer(
             "Would you like to continue with the decryption?",
